ActiveRebateBean class

Constructors

ActiveRebateBean({String rebateAmount = "", String firstChargeAmount = "", int state = 0, List<RebateInfoBean> rebateInfo = const []})
ActiveRebateBean.fromJson(Map<String, dynamic> json)

Properties

firstChargeAmount String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
rebateAmount String
getter/setter pair
rebateInfo List<RebateInfoBean>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state int
getter/setter pair

Methods

btnView(dynamic context, dynamic request, dynamic getRebate) Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
totalView(dynamic context) Widget

Operators

operator ==(Object other) bool
The equality operator.
inherited