PropsInfoBean class

Constructors

PropsInfoBean({String amount = "", int state = 0, PropsItem? props1, PropsItem? props2, PropsItem? props3})
PropsInfoBean.fromJson(Map<String, dynamic> json)

Properties

amount ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
props ↔ List<PropsItem>
getter/setter pair
props1 ↔ PropsItem?
getter/setter pair
props2 ↔ PropsItem?
getter/setter pair
props3 ↔ PropsItem?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ int
getter/setter pair

Methods

getTotal(dynamic context, dynamic request) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onClick(dynamic context, dynamic request) → dynamic
propsTotalView(dynamic context, dynamic request) → Widget
propsView() → Widget
showConfrim(dynamic context) → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited