PropsItem class

Constructors

PropsItem({String name = "", String icon = "", int count = 0, int id = 0})
PropsItem.fromJson(Map<String, dynamic> json)

Properties

count ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
icon ↔ String
getter/setter pair
id ↔ int
getter/setter pair
name ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited