SdkCustomAd class

Model - SDK自定义广告

Constructors

SdkCustomAd({required String adKey, required String adValue})
SdkCustomAd.fromJson(Map<String, dynamic> json)

Properties

adKey String
广告跳转类型
getter/setter pair
adValue String
广告跳转值
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited