BackpackBean class

Constructors

BackpackBean({int propsCount = 0, int propsId = 0, String icon = "", String propsName = "", num id = 0, num userId = 0, int propsType = 0, int buttonOrLabel = 0, int userNobility = 0, int propsNobility = 0})
BackpackBean.fromJson(Map<String, dynamic> json)

Properties

buttonOrLabel ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ double
getter/setter pair
icon ↔ String
getter/setter pair
id ↔ num
getter/setter pair
propsCount ↔ int
getter/setter pair
propsId ↔ int
getter/setter pair
propsName ↔ String
getter/setter pair
propsNobility ↔ int
getter/setter pair
propsType ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId ↔ num
getter/setter pair
userNobility ↔ int
getter/setter pair
width ↔ double
getter/setter pair

Methods

getBottomView(dynamic onTap(int type)) → Widget
getIcon() → Widget
getName() → Widget
getPropsNum() → Widget
getSpace(dynamic w) → Widget
getView(dynamic w, dynamic h, dynamic onTap(int type)) → Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited