BlackListMo class

Constructors

BlackListMo({String? targetUserNickname, String? targetUserIcon, String? converseId, String? targetUserId, bool? atten, int? nobilityType})
BlackListMo.fromJson(Map<String, dynamic> json)

Properties

atten bool?
getter/setter pair
converseId String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
nobilityType int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetUserIcon String?
getter/setter pair
targetUserId String?
getter/setter pair
targetUserNickname String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited