fansModel class

Constructors

fansModel({int? gender, String? levelIcon, String? personalSign, int? state, String? userIcon, String? userId, String? userLevel, String? userName, bool? atten, int? nobilityType})
fansModel.fromJson(Map<String, dynamic> json)

Properties

atten ↔ bool?
getter/setter pair
gender ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
levelIcon ↔ String?
getter/setter pair
nobilityType ↔ int?
getter/setter pair
personalSign ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ int?
getter/setter pair
userIcon ↔ String?
getter/setter pair
userId ↔ String?
getter/setter pair
userLevel ↔ String?
getter/setter pair
userName ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited