HomeClsModel class

clsName string 分类名称 fixedType number 固定分类直播列表传参用这个,非固定分类用id 类型 1 关注、2 热门、3 颜值、4 新人、5 收费 id number isFixed number 是否固定分类 0:非固定分类,1:固定分类 isHot number 预留字段。是否热门 0:非热门,1:热门

Constructors

HomeClsModel(String? clsName, int? fixedType, int? id, int? isFixed, int? isHot)
HomeClsModel.fromJson(Map<String, dynamic> json)

Properties

clsName String?
getter/setter pair
fixedType int?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int?
getter/setter pair
isFixed int?
getter/setter pair
isHot int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isAttentionTab() bool
关注TAB
isFixedTab() bool
isHotTab() bool
热门TAB
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fixedTypeHot → const int