FirstRechargeInfoEntity class

Constructors

FirstRechargeInfoEntity({required int amount, required int giftValue, required int label, required List<FirstRechargeGiftEntity> gifts})
FirstRechargeInfoEntity.fromJson(dynamic json)

Properties

amount int
getter/setter pair
gifts List<FirstRechargeGiftEntity>
getter/setter pair
giftValue int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
label int
getter/setter pair
packageCoin int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited