LuckInfoModel class

Constructors

LuckInfoModel({int lotteryNum = 0, int currentNum = 0, int luckyBurstTime = 0, int maxNum = 0, bool luckyBurst = false})
LuckInfoModel.fromJson(Map<String, dynamic> json)

Properties

currentNum ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isNorTab ↔ bool
getter/setter pair
lotteryNum ↔ int
getter/setter pair
luckyBurst ↔ bool
getter/setter pair
luckyBurstTime ↔ int
getter/setter pair
maxNum ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited