LuckItemModel class

Constructors

LuckItemModel({String color = "", int pos = 1, int propsNum = 1, int propsId = 0, String propsName = "", String prizeRate = "", String propsIcon = "", int colorType = 1})
LuckItemModel.fromJson(Map<String, dynamic> json)

Properties

color ↔ String
getter/setter pair
colorType ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pos ↔ int
getter/setter pair
prizeRate ↔ String
getter/setter pair
propsIcon ↔ String
getter/setter pair
propsId ↔ int
getter/setter pair
propsName ↔ String
getter/setter pair
propsNum ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBgColor() → Color
getPropsName() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited