LuckMarqueeModel class

Constructors

LuckMarqueeModel({int user_id = 0, String props_name = "", String user_nickname = "", int props_num = 0, int lottery_num = 0})
LuckMarqueeModel.fromJson(Map<String, dynamic> json)

Properties

hashCode → int
The hash code for this object.
no setterinherited
lottery_num ↔ int
getter/setter pair
props_name ↔ String
getter/setter pair
props_num ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
user_id ↔ int
getter/setter pair
user_nickname ↔ String
getter/setter pair

Methods

dealNickName() → String
getText() → Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited