LuckRecordModel class

Constructors

LuckRecordModel({List<LuckItemModel> prizes = const [], String lotteryTime = "", String lotteryName = ""})
LuckRecordModel.fromJson(Map<String, dynamic> json)

Properties

hashCode → int
The hash code for this object.
no setterinherited
lotteryName ↔ String
getter/setter pair
lotteryTime ↔ String
getter/setter pair
prizes ↔ List<LuckItemModel>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited