NobilityPicMo class

Constructors

NobilityPicMo({required String name, required String svga, required String icon})
NobilityPicMo.fromJson(dynamic json)

Properties

hashCode int
The hash code for this object.
no setterinherited
icon String
getter/setter pair
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
svga String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited