UserModel class

Constructors

UserModel({int? accountType, String? anchorIcon, String? anchorLevel, String? attenCnt, String? fansCnt, int? gender, String? id, String? levelIcon, String? myInviteCode, String? phone, String? userCls, String? userIcon, String? userLevel, String? userName, int? userApplyAnchorState, int? nobilityType})
UserModel.fromJson(Map<String, dynamic> json)

Properties

accountType ↔ int?
getter/setter pair
anchorIcon ↔ String?
getter/setter pair
anchorLevel ↔ String?
getter/setter pair
attenCnt ↔ String?
getter/setter pair
fansCnt ↔ String?
getter/setter pair
gender ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
levelIcon ↔ String?
getter/setter pair
myInviteCode ↔ String?
getter/setter pair
nobilityType ↔ int?
getter/setter pair
phone ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userApplyAnchorState ↔ int?
getter/setter pair
userCls ↔ String?
getter/setter pair
userIcon ↔ String?
getter/setter pair
userLevel ↔ String?
getter/setter pair
userName ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited