CoinConsumeBean class

Constructors

CoinConsumeBean(String action, int coin, String createTime, String desc, String giftIcon, int num, String payDesc, String playDesc, String userIcon, String userName, String userId, String change, String extParam)
CoinConsumeBean.fromJson(Map<String, dynamic> json)

Properties

action String
getter/setter pair
change String
getter/setter pair
coin int
getter/setter pair
createTime String
getter/setter pair
desc String
getter/setter pair
extParam String
getter/setter pair
giftIcon String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
num int
getter/setter pair
payDesc String
getter/setter pair
playDesc String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userIcon String
getter/setter pair
userId String
getter/setter pair
userName String
getter/setter pair

Methods

getGiftIcon() Widget
getRichText(bool isLive) InlineSpan
getUserIcon() Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
toUserHome(BuildContext context) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

ADMIN_SEND → const String
ADMIN_SUB → const String
BUY_COIN → const String
CHANGE_NAME → const String
GIFT → const String
GIFT_BJ → const String
LIVE_GAME_BJ → const String
LIVE_GUA → const String
LIVE_NOB → const String
LIVE_ONE → const String
LIVE_ONE_BJ → const String
LIVE_TIME → const String
LIVE_TIME_BJ → const String
NOB_OPEN → const String
NOB_OPEN_GIFT → const String
NOB_RENEW → const String
NOB_RENEW_GIFT → const String
ROLL → const String
ROLL_BJ → const String
SYSTEM_SEND → const String
SYSTEM_SUB → const String