LiveRecordBean class

Constructors

LiveRecordBean({num id = 0, String title = "", String startTime = "", String coverUrl = "", String totalIncome = "", num watchUsers = 0})
LiveRecordBean.fromJson(Map<String, dynamic> json)

Properties

coverUrl String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id num
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTime String
getter/setter pair
title String
getter/setter pair
totalIncome String
getter/setter pair
watchUsers num
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited