LiveRecordDetailBean class

Constructors

LiveRecordDetailBean({String? userName, num? changeCoin, num? changeCount, String? gmtCreate, num? price, int? type})
LiveRecordDetailBean.fromJson(Map<String, dynamic> json)

Properties

changeCoin num?
getter/setter pair
changeCount num?
getter/setter pair
gmtCreate String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
price num?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type int?
getter/setter pair
userName String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited