AccountContainer class

Constructors

AccountContainer({num useOrNot = 1, String tips = "", List<AccountBean> account = const []})
AccountContainer.fromJson(Map<String, dynamic> json)

Properties

account ↔ List<AccountBean>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tips ↔ String
getter/setter pair
useOrNot ↔ num
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited