ParamManager class

接口配置参数管理

Properties

hashCode → int
The hash code for this object.
no setterinherited
paramModel ↔ ParamModel?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAnchorDownloadAddress() → String
获取主播端下载地址
getAnchorPtUrl() → String
获取商户Pt群地址
getDownloadAddress() → String
获取主播端下载地址
getGooggleVerifyAddress() → String
获取谷歌验证使用教程地址
getJcApplicationHost() → String
金蟾应用域名
getJcUrl() → String
getJcWebSocketHost() → String
金蟾WebSocket域名
getJcWebViewHost() → String
金蟾WebView域名
getMerchantHomeDesc() → String
商户回家文字描述
getMerchantHomeIconUrl() → String
商户回家的IconUrl
getMerchantHomeUrl() → String
商户回家地址(用于跳转)
getMerchantPromoteBgPicUrl() → String
商户推广页面图片地址
getModifyNicknameNeedCoin() → int
修改昵称需要消耗金币 return 如果返回-1,则数据没有拉取到,界面不与显示
getOfficialAddress() → String
获取官网地址
getPtDownloadUrl() → String
获取Pt下载地址
getPtManageAccount() → String
获取Pt管理员账号
getPtManageAccountUrl() → String
获取Pt管理员账号url
getPtUrl() → String
获取Pt群地址
getShareDomain() → String
获取分享域名 shareDomain 格式为 "http://xxx,http://xxx1"
getTgDownloadUrl() → String
获取tg下载地址
init() → dynamic
isRankEntryEnable() → bool
排行榜入口是否开启(后端如果没配置,默认-开启)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

getInstance → ParamManager
no setter