CommonDialog class

Inheritance
Available extensions

Constructors

CommonDialog({Key? key, Widget? contentChild, String? title, TextAlign? titleAlign, TextStyle? titleStyle, double? titleFontSize, Color? titleColor, String? content, TextAlign? contentAlign, TextStyle? contentStyle, double? contentFontSize, Color? contentColor, String? leftButton, TextStyle? leftButtonTextStyle, VoidCallback? onLeftButtonPressed, String? rightButton, TextStyle? rightButtonTextStyle, VoidCallback? onRightButtonPressed, bool disableCloseEvent = false})
CommonDialog.normal({Key? key, required BuildContext context, bool showTitle = true, String? title, TextAlign? titleAlign, Widget? contentChild, String? content, TextAlign? contentAlign, bool showOneButton = false, String? cancelButton, String? confirmButton, VoidCallback? onCancel, VoidCallback? onConfirm, bool disableCloseEvent = false, bool dismissOnConfirmBtnClicked = true})
一般类型弹窗。包含默认的标题"温馨提示",自定义内容content,左下角"取消"按钮,右下角"确定"按钮
CommonDialog.singleButton({Key? key, Widget? contentChild, String? title, TextAlign? titleAlign, TextStyle? titleStyle, double? titleFontSize, Color? titleColor, String? content, TextAlign? contentAlign, TextStyle? contentStyle, double? contentFontSize, Color? contentColor, String? button, TextStyle? buttonTextStyle, VoidCallback? onButtonPressed})
单按钮弹窗

Properties

alignment → AlignmentGeometry?
How to align the Dialog.
finalinherited
backgroundColor → Color?
The background color of the surface of this Dialog.
finalinherited
child → Widget?
The widget below this widget in the tree.
finalinherited
clipBehavior → Clip?
Controls how the contents of the dialog are clipped (or not) to the given shape.
finalinherited
constraints → BoxConstraints?
Constrains the size of the dialog.
finalinherited
elevation → double?
The z-coordinate of this Dialog.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
insetAnimationCurve → Curve
The curve to use for the animation shown when the system keyboard intrudes into the space that the dialog is placed in.
finalinherited
insetAnimationDuration → Duration
The duration of the animation to show when the system keyboard intrudes into the space that the dialog is placed in.
finalinherited
insetPadding → EdgeInsets?
The amount of padding added to MediaQueryData.viewInsets on the outside of the dialog. This defines the minimum space between the screen's edges and the dialog.
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticsRole → SemanticsRole
The role this dialog represent in assist technologies.
finalinherited
shadowColor → Color?
The color used to paint a drop shadow under the dialog's Material, which reflects the dialog's elevation.
finalinherited
shape → ShapeBorder?
The shape of this dialog's border.
finalinherited
surfaceTintColor → Color?
The color used as a surface tint overlay on the dialog's background color, which reflects the dialog's elevation.
finalinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
inherited
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeAllPadding(BuildContext context) → dynamic

Available on Widget, provided by the WidgetExtension extension

removePadding(BuildContext context, {bool removeLeft = false, bool removeTop = false, bool removeRight = false, bool removeBottom = false}) → dynamic

Available on Widget, provided by the WidgetExtension extension

showAsDialog(BuildContext context, {bool barrierDismissible = true, Color? barrierColor}) → dynamic

Available on Widget, provided by the WidgetExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited