BigTurnTableView class

Widget 大转盘

Inheritance
Available extensions

Constructors

BigTurnTableView({Key? key, required String roomId, required String anchorId, required bool isInAnchorSide, ImTurntable? imTurntable, VoidCallback? onTurnAnimFinish})
const

Properties

anchorId String
主播ID
final
bgRadius double
圆盘背景半径
final
hashCode int
The hash code for this object.
no setterinherited
imTurntable ImTurntable?
开播端的中奖数据
final
isInAnchorSide bool
是否为在主播端显示
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onTurnAnimFinish VoidCallback?
大转盘转动结束(如果是开播端,需要传递这个事件)
final
radius double
圆盘旋转区域半径
final
roomId String
房间ID
final
rotateMilliseconds int
大转盘旋转时间(默认:5秒)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<BigTurnTableView>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeAllPadding(BuildContext context) → dynamic

Available on Widget, provided by the WidgetExtension extension

removePadding(BuildContext context, {bool removeLeft = false, bool removeTop = false, bool removeRight = false, bool removeBottom = false}) → dynamic

Available on Widget, provided by the WidgetExtension extension

showAsDialog(BuildContext context, {bool barrierDismissible = true, Color? barrierColor}) → dynamic

Available on Widget, provided by the WidgetExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited