ImGiftMsg class

礼物:普通礼物;动画礼物;大型礼物(全直播间广播横幅礼物)

Constructors

ImGiftMsg({required String nn, required String uIc, required String gId, required int gn, required String gIc, required String gfn, required int gt, required int not, required String uid, required int lv})
ImGiftMsg.fromJson(dynamic json)

Properties

gfn String
getter/setter pair
gIc String
getter/setter pair
gId String
getter/setter pair
gn int
getter/setter pair
gt int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lv int
getter/setter pair
nn String
getter/setter pair
not int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uIc String
getter/setter pair
uid String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited