SocketImManager class

Inheritance

Constructors

SocketImManager()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → dynamic
退出直播间时关闭
override
getProxy() → ImMessageObserverProxy
override
init() → dynamic
app启动式初始化
override
join({required String id, String? anchorId}) → dynamic
加入直播间
override
login({String? auth}) → dynamic
连接socket
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
release() → dynamic
app关闭时销毁
override
reset() → dynamic
每次进入直播间先reset
override
send(String msg) → dynamic
socket发送消息
override
sendMessage({required String authorId, required String msg, bool isBarrage = false, dynamic onSuccess(dynamic)?, dynamic onError(ErrorEntity)?}) → dynamic
发送聊天消息
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

MAX_OFFLINE_DURATION → const int
PING → const String
PING_DURATION → const int
PING_DURATION_IN_LIVE_ROOM → const int
PONG → const String
TIMER_INTERVAL → const int