BoostRouter class

Constructors

BoostRouter()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

applyAnchor(BuildContext context) → Future
申请主播
generateDefaultRouteName({String type = ""}) → String
innerDialog<T>({required BuildContext context, required WidgetBuilder builder, bool barrierDismissible = true, Color? barrierColor = Colors.black54, String? barrierLabel, bool useSafeArea = true, bool useRootNavigator = true, String? name, Offset? anchorPoint}) → Future<T?>
innerPush(BuildContext context, WidgetBuilder builder, {String? name}) → Future
内部匿名路由跳转 只能在当前flutter页面内跳转,无需提供给业务方或新开flutter页面
popAllLivePages(BuildContext context) → void
主页可能嵌入业务方,所以不关闭,关闭所有直播页面

Constants

carPage → const String
homePage → const String
initPage → const String
liveRoomPage → const String
myLivePage → const String
noblePage → const String
rankPage → const String
routeNamePrefix → const String
searchPage → const String