LiveSdkCallback class

Constructors

LiveSdkCallback({dynamic onNeedLogin(BuildContext context)?, Future onRecharge(BuildContext context)?, dynamic onUserOffline(BuildContext context)?, dynamic onCustomAdClick(BuildContext context, String id, int type, int location, String key, String value)?, bool onCheckLiveRoomPermission(BuildContext context)?})

Properties

hashCode int
The hash code for this object.
no setterinherited
onCheckLiveRoomPermission bool Function(BuildContext context)?
final
onCustomAdClick → dynamic Function(BuildContext context, String id, int type, int location, String key, String value)?
final
onNeedLogin → dynamic Function(BuildContext context)?
final
onRecharge Future Function(BuildContext context)?
final
onUserOffline → dynamic Function(BuildContext context)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited