AppSettings class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

barrageCnt → int
no setter
isBarrageOn → bool
no setter
isCarEffectsOn → bool
no setter
isGiftEffectsOn → bool
no setter

Static Methods

setBarrageCnt(int cnt) → void
setBarrageSwitch(bool on) → void
setCarEffectSwitch(bool on) → void
setGiftEffectsSwitch(bool on) → void