MultiPinyin class

多音字

Constructors

MultiPinyin({String? word, String? pinyin})

Properties

hashCode → int
The hash code for this object.
no setterinherited
pinyin ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
word ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited