CityModel class

Constructors

CityModel({required String? name, String? tagIndex, String? namePinyin, String? code})
CityModel.fromJson(Map<String, dynamic> json)

Properties

code ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isShowSuspension ↔ bool
getter/setter pairinherited
name ↔ String?
getter/setter pair
namePinyin ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tagIndex ↔ String?
getter/setter pair

Methods

getSuspensionTag() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited