DynamicUtils class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decodeData(dynamic data) → dynamic
doubleToString(double source, {int fixed = 2, bool finishZero = false}) → String
double转string
safeToBool(dynamic source, {bool def = false}) → bool
将其他类型转换为int
safeToDouble(dynamic source, {double def = 0}) → double
将其他类型转换为double
safeToInt(dynamic source, {int def = 0}) → int
将其他类型转换为int
safeToString(dynamic source, {String? def}) → String
将其他类型转换为String