DeviceManager class

设备管理

Constructors

DeviceManager()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
keyIOSDeviceId → String
IOS 设备码 钥匙串KEY
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getDeviceCompany() → String
获取设备厂商
getDeviceId() → String?
获取设备ID
getDeviceModel() → String
获取设备型号
getDeviceOS() → String
获取设备操作系统
initDeviceId() → dynamic
初始化设备ID,并存入SP中
initDeviceInfo() → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited