RepaintBoundaryUtils class

Constructors

RepaintBoundaryUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
savePhoto({VoidCallback? onStart, VoidCallback? onFinish}) → void
保存到相册 onFinish 是否保存结束
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited