UserManager class

用户管理(当前登录用户)

Constructors

UserManager()
factory

Properties

auth ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userModel ↔ UserModel?
getter/setter pair

Methods

clearAuth() → void
清除Auth信息
clearUserModel() → void
清空当前用户信息
getAuth() → String?
获取Auth信息
getMultiLoginState() → bool
获得多端登录被挤的状态
getUserId() → String
当前登录用户ID
getUserModel() → UserModel?
获取当前用户信息
hadLogin() → bool
hasBindPhone() → bool
用户是否绑定手机号
isAnchor() → bool
是否为主播(当前登录用户)
isFirstInstallApp() → bool
是否用户首次安装APP(默认:true)
isUserLogin() → bool
用户是否登录(根据用户信息是否有绑定的手机号判断)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveUserModel(Map<String, dynamic> userInfoMap) → UserModel?
保存当前用户信息
setFirstInstallApp(bool installState) → dynamic
设置是否用户首次安装APP installState 首次安装状态
setMultiLoginState(bool state) → void
记录多端登录被挤的状态
toString() → String
A string representation of this object.
inherited
updateAuth(String? auth) → void
更新Auth信息

Operators

operator ==(Object other) → bool
The equality operator.
inherited