DoubleValue class

Constructors

DoubleValue()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

appBarHeight double
默认只有标题的高度
no setter
appBarMaxHeight double
带有toolbar的高度
no setter
bottomHeight double
no setter
默认只有状态栏+标题的高度
no setter
带有状态栏+标题+toolbar的高度
no setter
padding EdgeInsets
no setter
screenHeight double
no setter
screenWidth double
no setter
statusBarHeight double
no setter

Constants

titleBarHeight → const double
默认只有标题的高度