AppSwitch class

Inheritance
Available extensions

Constructors

AppSwitch({Key? key, required bool value, required ValueChanged<bool>? onChanged, Color? activeColor = colorOrangeRed, Color? trackColor = Colors.grey, Color? thumbColor = Colors.white})
const

Properties

activeColor → Color?
The color to use for the track when the switch is on.
no setterinherited
activeThumbImage → ImageProvider<Object>?
An image to use on the thumb of this switch when the switch is on.
finalinherited
activeTrackColor → Color?
The color to use for the track when the switch is on.
finalinherited
applyTheme → bool?
Whether to apply the ambient CupertinoThemeData.
finalinherited
autofocus → bool
True if this widget will be selected as the initial focus when no other node in its scope is currently focused.
finalinherited
dragStartBehavior → DragStartBehavior
Determines the way that drag start behavior is handled.
finalinherited
focusColor → Color?
The color to use for the focus highlight for keyboard interactions.
finalinherited
focusNode → FocusNode?
An optional focus node to use as the focus node for this widget.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
inactiveThumbColor → Color?
The color to use on the thumb when the switch is off.
finalinherited
inactiveThumbImage → ImageProvider<Object>?
An image to use on the thumb of this switch when the switch is off.
finalinherited
inactiveTrackColor → Color?
The color to use for the track when the switch is off.
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
mouseCursor → WidgetStateProperty<MouseCursor>?
The cursor for a mouse pointer when it enters or is hovering over the widget.
finalinherited
offLabelColor → Color?
The color to use for the accessibility label when the switch is off.
finalinherited
onActiveThumbImageError → ImageErrorListener?
An optional error callback for errors emitted when loading activeThumbImage.
finalinherited
onChanged → ValueChanged<bool>?
Called when the user toggles the switch on or off.
finalinherited
onFocusChange → ValueChanged<bool>?
Handler called when the focus changes.
finalinherited
onInactiveThumbImageError → ImageErrorListener?
An optional error callback for errors emitted when loading inactiveThumbImage.
finalinherited
onLabelColor → Color?
The color to use for the accessibility label when the switch is on.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbColor → Color?
The color to use for the thumb when the switch is on.
finalinherited
thumbIcon → WidgetStateProperty<Icon?>?
The icon to use on the thumb of this switch.
finalinherited
trackColor → Color?
The color to use for the track when the switch is off.
no setterinherited
trackOutlineColor → WidgetStateProperty<Color?>?
The outline color of this CupertinoSwitch's track.
finalinherited
trackOutlineWidth → WidgetStateProperty<double?>?
The outline width of this CupertinoSwitch's track.
finalinherited
value → bool
Whether this switch is on or off.
finalinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<CupertinoSwitch>
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeAllPadding(BuildContext context) → dynamic

Available on Widget, provided by the WidgetExtension extension

removePadding(BuildContext context, {bool removeLeft = false, bool removeTop = false, bool removeRight = false, bool removeBottom = false}) → dynamic

Available on Widget, provided by the WidgetExtension extension

showAsDialog(BuildContext context, {bool barrierDismissible = true, Color? barrierColor}) → dynamic

Available on Widget, provided by the WidgetExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited