JJDialogAlert class

Inheritance
Available extensions

Constructors

JJDialogAlert({Key? key, Widget? title, String? titleStr, Widget? content, String? contentStr, Widget? cancel, String? cancelStr, Widget? confirm, String? confirmStr, TextStyle? titleStyle, TextStyle? contentStyle, TextStyle? cancelStyle, TextStyle? confirmStyle, EdgeInsetsGeometry contentPadding = const EdgeInsets.all(20), double spaceBetween = 20, double actionHeight = 49, dynamic cancelTap()?, dynamic confirmTap()?, bool canDismiss = true})
const

Properties

actionHeight → double
final
cancel → Widget?
final
cancelStr → String?
final
cancelStyle → TextStyle?
final
cancelTap → dynamic Function()?
final
canDismiss → bool
final
confirm → Widget?
final
confirmStr → String?
final
confirmStyle → TextStyle?
final
confirmTap → dynamic Function()?
final
content → Widget?
final
contentPadding → EdgeInsetsGeometry
内容区域(title & content)
final
contentStr → String?
final
contentStyle → TextStyle?
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spaceBetween → double
title - content
final
title → Widget?
final
titleStr → String?
final
titleStyle → TextStyle?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<JJDialogAlert>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeAllPadding(BuildContext context) → dynamic

Available on Widget, provided by the WidgetExtension extension

removePadding(BuildContext context, {bool removeLeft = false, bool removeTop = false, bool removeRight = false, bool removeBottom = false}) → dynamic

Available on Widget, provided by the WidgetExtension extension

showAsDialog(BuildContext context, {bool barrierDismissible = true, Color? barrierColor}) → dynamic

Available on Widget, provided by the WidgetExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited