JJDialogController class

Constructors

JJDialogController({JJDialogPosition position = JJDialogPosition.bottom, Color barrierColor = Colors.black54, Color? backgroundColor = Colors.transparent, ShapeBorder? shape, double? elevation, Duration insetAnimationDuration = const Duration(milliseconds: 100), Curve insetAnimationCurve = Curves.decelerate, EdgeInsets insetPadding = const EdgeInsets.symmetric(horizontal: 0.0, vertical: 0.0), Clip clipBehavior = Clip.none, AlignmentGeometry? alignment, Widget? child, JJDialogContainer? dialogContainer, Offset? anchorPoint, bool useRootNavigator = false, bool barrierDismissible = true, String? barrierLabel, bool useSafeArea = true, bool isScrollControlled = false, bool isDismissible = true, bool enableDrag = true, AnimationController? transitionAnimationController})

Properties

alignment → AlignmentGeometry?
final
anchorPoint → Offset?
final
backgroundColor → Color?
通用
final
barrierColor → Color
final
barrierDismissible ↔ bool
getter/setter pair
barrierLabel → String?
final
child → Widget?
任意自定义widget,而且设置了child会优先使用
final
clipBehavior → Clip
final
dialogContainer → JJDialogContainer?
使用已实现的JJDialog
final
elevation → double?
final
enableDrag → bool
是否允许拖拽
final
hashCode → int
The hash code for this object.
no setterinherited
insetAnimationCurve → Curve
final
insetAnimationDuration → Duration
final
insetPadding ↔ EdgeInsets
getter/setter pair
isDismissible → bool
final
isScrollControlled → bool
bottom类型特有 有最大高度限定,如果要突破这个高度,需要设为true
final
position ↔ JJDialogPosition
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape ↔ ShapeBorder?
The shape of this dialog's border.
getter/setter pair
transitionAnimationController → AnimationController?
final
useRootNavigator → bool
final
useSafeArea → bool
final

Methods

dismiss(BuildContext context) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
show(BuildContext context) → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited