JJDialogList class

Inheritance
Available extensions

Constructors

JJDialogList({Key? key, JJDialogType type = JJDialogType.list, List<String>? list, List<Widget>? children, Widget? custom, double cellHeight = 44, double cellWidth = double.infinity, EdgeInsets? listPadding = const EdgeInsets.symmetric(horizontal: 16), EdgeInsets? cellPadding, TextAlign? textAlign = TextAlign.center, TextStyle? textStyle, TextStyle? selectedTextStyle, BoxDecoration? cellDecoration, BoxDecoration? cellSelectedDecoration, void onTap(int index)?, int selectedIndex = -1, Color? highlightColor, Color? tapSplashColor, BorderRadius? tapBorderRadius, Color separateColor = const Color(0xfff5f5f5), double separateWidth = 0.5, int crossAxisCount = 3, double mainAxisSpacing = 0.0, double crossAxisSpacing = 0.0, double childAspectRatio = 1.0, double? mainAxisExtent, double diameterRatio = 1.07, Color? backgroundColor = Colors.transparent, double offAxisFraction = 0.0, bool useMagnifier = true, double magnification = 1.2, FixedExtentScrollController? scrollController, double squeeze = 1.45, Widget? selectionOverlay, void onChange(int index)?})

Properties

backgroundColor → Color?
final
cellDecoration → BoxDecoration?
final
cellHeight → double
final
cellPadding → EdgeInsets?
cell选项卡
final
cellSelectedDecoration → BoxDecoration?
final
cellWidth → double
final
childAspectRatio → double
final
children → List<Widget>?
final
crossAxisCount → int
gridView
final
crossAxisSpacing → double
final
custom → Widget?
custom
final
diameterRatio → double
picker
final
hashCode → int
The hash code for this object.
no setterinherited
highlightColor → Color?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
list → List<String>?
默认为list
final
listPadding → EdgeInsets?
final
magnification → double
final
mainAxisExtent → double?
final
mainAxisSpacing → double
final
offAxisFraction → double
final
onChange → void Function(int index)?
final
onTap → void Function(int index)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollController → FixedExtentScrollController?
final
selectedIndex ↔ int
getter/setter pair
selectedTextStyle → TextStyle?
final
selectionOverlay → Widget?
final
separateColor → Color
list, listHeight 44, 文字居中
final
separateWidth → double
final
squeeze → double
final
tapBorderRadius → BorderRadius?
final
tapSplashColor → Color?
final
textAlign → TextAlign?
final
textStyle → TextStyle?
final
type → JJDialogType
final
useMagnifier → bool
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<JJDialogList>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeAllPadding(BuildContext context) → dynamic

Available on Widget, provided by the WidgetExtension extension

removePadding(BuildContext context, {bool removeLeft = false, bool removeTop = false, bool removeRight = false, bool removeBottom = false}) → dynamic

Available on Widget, provided by the WidgetExtension extension

showAsDialog(BuildContext context, {bool barrierDismissible = true, Color? barrierColor}) → dynamic

Available on Widget, provided by the WidgetExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited