JJDialogUtils class

Constructors

JJDialogUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

hideLoading(BuildContext context) → dynamic
showAlert(BuildContext context, {String? titleStr, String? contentStr, String? cancel, String? confirm, Widget? title, Widget? content, dynamic cancelTap()?, dynamic confirmTap()?}) → dynamic
alert
showAnchorType(BuildContext context, {int type = -1, dynamic onTap(int anchorType)?}) → dynamic
选择主播类型
showAwardRankList(BuildContext context, {int type = 0}) → dynamic
大转盘榜单 type:0 dialog, 1 push
showGuardList(BuildContext context, String liveId, String anchorId, {OnUserPressed? onTap}) → dynamic
守护列表 liveId:直播间ID anchorId:主播ID
showGuardOpen(BuildContext context, String liveId, dynamic onTap(int index)?) → dynamic
守护开通 liveId:直播间ID
showLoading(BuildContext context, {String? text}) → dynamic
只适合在当前页面展示,对于一个已经销毁的widget,调用hideLoading会有问题,建议使用JJLoadingUtils 已废弃,使用JJLoadingUtils.showLoading代替JJDialogUtils.showLoading
showRankAlert(BuildContext context, dynamic onTap()?) → dynamic
榜单隐身-弹框
showRankList(BuildContext context, String anchorId) → dynamic
直播间榜单 anchorId:主播ID
showUserList(BuildContext context, String liveId, String anchorId, {OnUserPressed? onTap}) → dynamic
直播间在线用户列表 liveId:直播间ID anchorId:主播ID