CfgList class

Constructors

CfgList({String name = '', int days = 0, String iconUrl = '', int guardType = 1, int coin = 0})
CfgList.fromJson(Map<String, dynamic> json)
factory

Properties

coin int
getter/setter pair
days int
getter/setter pair
guardType int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
iconUrl String
getter/setter pair
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited