JJGuardList class

Inheritance
Available extensions

Constructors

JJGuardList({Key? key, double height = 550, double width = double.infinity, BoxConstraints? constraints, BoxDecoration? decoration, EdgeInsetsGeometry? padding, EdgeInsetsGeometry? margin, Clip clipBehavior = Clip.none, bool isTapDismiss = true, AppBar? appBar, Widget? content, List<String>? tabs, List<Widget>? children, required String liveId, dynamic onTap(String userId)?, required bool showOpenGuard})
const

Properties

appBar AppBar?
appBar
final
children List<Widget>?
final
clipBehavior Clip
final
constraints BoxConstraints?
final
content Widget?
content 自定义组件必须 type为custom
final
decoration BoxDecoration?
final
hashCode int
The hash code for this object.
no setterinherited
height double
final
isTapDismiss bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
liveId String
final
margin EdgeInsetsGeometry?
final
onTap → dynamic Function(String userId)?
final
padding EdgeInsetsGeometry?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showOpenGuard bool
final
tabs List<String>?
tabBar
final
width double
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<JJGuardList>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeAllPadding(BuildContext context) → dynamic

Available on Widget, provided by the WidgetExtension extension

removePadding(BuildContext context, {bool removeLeft = false, bool removeTop = false, bool removeRight = false, bool removeBottom = false}) → dynamic

Available on Widget, provided by the WidgetExtension extension

showAsDialog(BuildContext context, {bool barrierDismissible = true, Color? barrierColor}) → dynamic

Available on Widget, provided by the WidgetExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited