GridPage class

通用GridView横向翻页组件

Inheritance
Available extensions

Constructors

GridPage({Key? key, required List<Widget> children, int column = 4, int row = 2, double columnSpacing = 0.0, double rowSpacing = 0.0, double itemRatio = 1.0, Color background = Colors.transparent, Color indicatorNormal = const Color(0x33FFFFFF), Color indicatorActive = const Color(0xFFFFFFFF), double indicatorWidth = 20, dynamic onPageChanged(int)?})
const

Properties

background → Color
final
children → List<Widget>
final
column → int
final
columnSpacing → double
final
hashCode → int
The hash code for this object.
no setterinherited
indicatorActive → Color
final
indicatorNormal → Color
final
indicatorWidth → double
final
itemRatio → double
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onPageChanged → dynamic Function(int)?
final
row → int
final
rowSpacing → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeAllPadding(BuildContext context) → dynamic

Available on Widget, provided by the WidgetExtension extension

removePadding(BuildContext context, {bool removeLeft = false, bool removeTop = false, bool removeRight = false, bool removeBottom = false}) → dynamic

Available on Widget, provided by the WidgetExtension extension

showAsDialog(BuildContext context, {bool barrierDismissible = true, Color? barrierColor}) → dynamic

Available on Widget, provided by the WidgetExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited