JJPickers class

Constructors

JJPickers()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

showDatePicker(BuildContext context, {JJDateMode mode = JJDateMode.YMD, JJPDuration? selectDate, JJPDuration? maxDate, JJPDuration? minDate, JJSuffix? suffix, JJPickerStyle? pickerStyle, JJDateCallback? onChanged, JJDateCallback? onConfirm, dynamic onCancel(bool isCancel)?, bool overlapTabBar = false}) → void
时间选择器 Suffix : 每列时间对应的单位 默认:中文常规 Suffix(years: '年',month: '月'); selectDate : 初始化选中时间 默认现在 PDuration.now(); PDuration.parse(DateTime.parse('20210139')); PDuration(year: 2020,month: 2); maxDate : 最大时间 用法同上 tip: 当只有单列数据,该限制不产生关联 只针对单列item限制,比如 maxDate>day = 3 minDate>day = 10,那么所有的月份都只显示3-10之间 minDate : 最小时间 用法同上 mode : 时间选择器所显示样式 16 种时间样式 默认:DateMode.YMD