JJLoading class

Inheritance
Available extensions

Constructors

JJLoading({Key? key, bool isValueListen = false, JJLoadingType loadingType = JJLoadingType.circularLoading, JJProgressType progressType = JJProgressType.circularProgress, Axis axis = Axis.vertical, Widget? loading, String? initialText, TextAlign textAlign = TextAlign.center, TextStyle? textStyle, double? value, Color? backgroundColor, Color? color, Animation<Color?>? valueColor, double radius = 20, AlignmentGeometry? alignment, EdgeInsetsGeometry? padding, Decoration? decoration, Decoration? foregroundDecoration, double? width, double? height, BoxConstraints? constraints, EdgeInsetsGeometry? margin, Matrix4? transform, AlignmentGeometry? transformAlignment, Widget? custom, Clip clipBehavior = Clip.none})

Properties

alignment → AlignmentGeometry?
container
final
axis → Axis
final
backgroundColor → Color?
final
clipBehavior → Clip
custom
final
color → Color?
final
constraints → BoxConstraints?
final
custom → Widget?
final
decoration → Decoration?
final
foregroundDecoration → Decoration?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
initialText ↔ String?
bottom
getter/setter pair
isValueListen → bool
是否监听文字,进度值变化
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loading → Widget?
top
final
loadingType → JJLoadingType
final
margin → EdgeInsetsGeometry?
final
padding → EdgeInsetsGeometry?
final
progressType → JJProgressType
final
radius → double
cupertinoActivityIndicator 指示器半径大小
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strokeWidth → double
final
textAlign → TextAlign
final
textStyle → TextStyle?
final
transform → Matrix4?
final
transformAlignment → AlignmentGeometry?
final
value ↔ double?
default loading(CircularProgressIndicator) 因为作为加载动画,所以不提供设置该值
getter/setter pair
valueColor → Animation<Color?>?
进度条以及指示器颜色
final
width → double?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<JJLoading>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeAllPadding(BuildContext context) → dynamic

Available on Widget, provided by the WidgetExtension extension

removePadding(BuildContext context, {bool removeLeft = false, bool removeTop = false, bool removeRight = false, bool removeBottom = false}) → dynamic

Available on Widget, provided by the WidgetExtension extension

showAsDialog(BuildContext context, {bool barrierDismissible = true, Color? barrierColor}) → dynamic

Available on Widget, provided by the WidgetExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited