JJTabBar class

Inheritance
Implemented types
Available extensions

Constructors

JJTabBar({Key? key, required List<Widget> tabs, TabController? controller, bool isCustomLayout = false, bool isScrollable = false, EdgeInsetsGeometry? padding, Color? indicatorColor, bool automaticIndicatorColorAdjustment = true, double indicatorWeight = 2.0, double indicatorWidth = 0.0, EdgeInsetsGeometry indicatorPadding = EdgeInsets.zero, Decoration? indicator, JJTabBarIndicatorSize indicatorSize = JJTabBarIndicatorSize.label, JJTabBarIndicatorType indicatorType = JJTabBarIndicatorType.line, Color? labelColor, TextStyle? labelStyle, EdgeInsetsGeometry? labelPadding, Color? unselectedLabelColor, TextStyle? unselectedLabelStyle, DragStartBehavior dragStartBehavior = DragStartBehavior.start, MaterialStateProperty<Color?>? overlayColor, MouseCursor? mouseCursor, bool? enableFeedback, ValueChanged<int>? onTap, ScrollPhysics? physics, InteractiveInkFeatureFactory? splashFactory, BorderRadius? splashBorderRadius})
const

Properties

automaticIndicatorColorAdjustment bool
final
controller TabController?
final
dragStartBehavior DragStartBehavior
final
enableFeedback bool?
final
hashCode int
The hash code for this object.
no setterinherited
indicator Decoration?
final
indicatorColor Color?
final
indicatorPadding EdgeInsetsGeometry
final
indicatorSize JJTabBarIndicatorSize
final
indicatorType JJTabBarIndicatorType
final
indicatorWeight double
final
indicatorWidth double
final
isCustomLayout bool
final
isScrollable bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelColor Color?
final
labelPadding EdgeInsetsGeometry?
final
labelStyle TextStyle?
final
mouseCursor MouseCursor?
final
onTap ValueChanged<int>?
final
overlayColor MaterialStateProperty<Color?>?
final
padding EdgeInsetsGeometry?
final
physics ScrollPhysics?
final
preferredSize Size
The size this widget would prefer if it were otherwise unconstrained.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
splashBorderRadius BorderRadius?
final
splashFactory InteractiveInkFeatureFactory?
final
tabHasTextAndIcon bool
no setter
tabs List<Widget>
final
unselectedLabelColor Color?
final
unselectedLabelStyle TextStyle?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<JJTabBar>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeAllPadding(BuildContext context) → dynamic

Available on Widget, provided by the WidgetExtension extension

removePadding(BuildContext context, {bool removeLeft = false, bool removeTop = false, bool removeRight = false, bool removeBottom = false}) → dynamic

Available on Widget, provided by the WidgetExtension extension

showAsDialog(BuildContext context, {bool barrierDismissible = true, Color? barrierColor}) → dynamic

Available on Widget, provided by the WidgetExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited