ShadowContainer class

带阴影的container,用来实现带阴影的框

Inheritance
Available extensions

Constructors

ShadowContainer({Key? key, double? height, double? width, EdgeInsetsGeometry? padding, Widget? child, Color? color = colorWhite, BorderRadiusGeometry borderRadius = const BorderRadius.all(Radius.circular(10)), Color shadowColor = colorBlack4, Offset offset = const Offset(0, 2), double blurRadius = 5, double spreadRadius = 2})

Properties

alignment → AlignmentGeometry?
Align the child within the container.
finalinherited
child → Widget?
The child contained by the container.
finalinherited
clipBehavior → Clip
The clip behavior when Container.decoration is not null.
finalinherited
color → Color?
The color to paint behind the child.
finalinherited
constraints → BoxConstraints?
Additional constraints to apply to the child.
finalinherited
decoration → Decoration?
The decoration to paint behind the child.
finalinherited
foregroundDecoration → Decoration?
The decoration to paint in front of the child.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
isAntiAlias → bool
Whether to apply anti-aliasing when painting the box.
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin → EdgeInsetsGeometry?
Empty space to surround the decoration and child.
finalinherited
padding → EdgeInsetsGeometry?
Empty space to inscribe inside the decoration. The child, if any, is placed inside this padding.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transform → Matrix4?
The transformation matrix to apply before painting the container.
finalinherited
transformAlignment → AlignmentGeometry?
The alignment of the origin, relative to the size of the container, if transform is specified.
finalinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
inherited
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeAllPadding(BuildContext context) → dynamic

Available on Widget, provided by the WidgetExtension extension

removePadding(BuildContext context, {bool removeLeft = false, bool removeTop = false, bool removeRight = false, bool removeBottom = false}) → dynamic

Available on Widget, provided by the WidgetExtension extension

showAsDialog(BuildContext context, {bool barrierDismissible = true, Color? barrierColor}) → dynamic

Available on Widget, provided by the WidgetExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited