ThemeGradientButton class

Inheritance
Available extensions

Constructors

ThemeGradientButton({Key? key, double? height = 45, double? width = double.infinity, required Gradient gradient, double radius = 25, bool isEnable = true, VoidCallback? onPressed, String text = "", double fontSize = 16, Color textColor = Colors.white, EdgeInsetsGeometry? padding, FontWeight? fontWeight})
const
ThemeGradientButton.theme1(String text, {bool isEnable = true, VoidCallback? onPressed, double height = 45, double? width, double radius = 25})
两种渐变主题色按钮
factory
ThemeGradientButton.theme2(String text, {bool isEnable = true, VoidCallback? onPressed, double height = 45, double radius = 25, double? width})
四种渐变主题色按钮
factory
ThemeGradientButton.theme3(String text, {bool isEnable = true, Gradient gradient = AppTheme.themeGradient3, double? width, double? height, double fontSize = 11, FontWeight? fontWeight, VoidCallback? onPressed})
小按钮两种颜色主题渐变
factory

Properties

fontSize → double
final
fontWeight → FontWeight?
final
gradient → Gradient
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
isEnable → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onPressed → VoidCallback?
final
padding → EdgeInsetsGeometry?
final
radius → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
final
textColor → Color
final
width → double?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeAllPadding(BuildContext context) → dynamic

Available on Widget, provided by the WidgetExtension extension

removePadding(BuildContext context, {bool removeLeft = false, bool removeTop = false, bool removeRight = false, bool removeBottom = false}) → dynamic

Available on Widget, provided by the WidgetExtension extension

showAsDialog(BuildContext context, {bool barrierDismissible = true, Color? barrierColor}) → dynamic

Available on Widget, provided by the WidgetExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited