ConverseListMo class
Constructors
Properties
-
childs
↔ List<
ConverseChildsMo> ? -
getter/setter pair
- converseId ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon ↔ String?
-
getter/setter pair
- lastMsgContent ↔ String?
-
getter/setter pair
- lastMsgTimeCn ↔ String?
-
getter/setter pair
- msgType ↔ int?
-
getter/setter pair
- nickname ↔ String?
-
getter/setter pair
- nobilityType ↔ int?
-
getter/setter pair
- role ↔ int?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetUserId ↔ String?
-
getter/setter pair
- unReadNum ↔ int?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited