RechargeRecordBean class
Constructors
Properties
- createTime ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- orderId ↔ String
-
getter/setter pair
- pkgCode ↔ String
-
getter/setter pair
- pkgName ↔ String
-
getter/setter pair
- rechargeMoney ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state ↔ String
-
getter/setter pair
- stateStr ↔ String
-
getter/setter pair
Methods
-
getStateStyle(
) → TextStyle -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited