RemainRecordBean class
Constructors
- RemainRecordBean({String coin = "", String createTime = "", String icon = "", String recordPrefix = "", String unitSuffix = ""})
-
RemainRecordBean.fromJson(Map<
String, dynamic> json)
Properties
- coin ↔ String
-
getter/setter pair
- createTime ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon ↔ String
-
getter/setter pair
- recordPrefix ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unitSuffix ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited