GameFastThreeItemModel class
Constructors
- GameFastThreeItemModel({String? odds, int? orderIndex, int? playType, String? showBtn, String? betChoice, int? baseCoin})
-
GameFastThreeItemModel.fromJson(Map<
String, dynamic> json)
Properties
- baseCoin ↔ int?
-
getter/setter pair
- betChoice ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- odds ↔ String?
-
getter/setter pair
- orderIndex ↔ int?
-
getter/setter pair
- playType ↔ int?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showBtn ↔ String?
-
getter/setter pair
Methods
-
equals(
GameConfirmBetItemModel? other) → bool - 是否与下注的Model是同一个下注项
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited