GameFollowVoteModel class
Constructors
-
GameFollowVoteModel({int? period, List<
GameConfirmBetItemModel> ? betOrders, List? multiList, int? state, int? timeLeft, int? openMultiSet, int? gameType}) - GameFollowVoteModel.fromJson(Map json)
Properties
-
betOrders
↔ List<
GameConfirmBetItemModel> ? -
getter/setter pair
- gameType ↔ int?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- multiList ↔ List?
-
getter/setter pair
- openMultiSet ↔ int?
-
getter/setter pair
- period ↔ int?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state ↔ int?
-
getter/setter pair
- timeLeft ↔ int?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited