Im class abstract
- Implementers
Constructors
- Im()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → dynamic - 退出直播间时关闭
-
getProxy(
) → ImMessageObserverProxy -
init(
) → dynamic - app启动式初始化
-
join(
{required String id, String? anchorId}) → dynamic - 加入直播间
-
login(
{String? auth}) → dynamic - 用户登录/切换账号后登录im
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
release(
) → dynamic - app关闭时销毁
-
reset(
) → dynamic - 每次进入直播间先reset
-
send(
String msg) → dynamic - socket发送消息
-
sendMessage(
{required String authorId, required String msg, bool isBarrage = false, dynamic onSuccess(dynamic)?, dynamic onError(ErrorEntity)?}) → dynamic - 发送聊天消息
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited