LiveSdkManager class
SDK接口管理
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
callback(
) → LiveSdkCallback? -
exitSDK(
BuildContext context) → dynamic - 登出SDK
-
getAppId(
) → String -
getEnv(
) → LiveEnv -
getToken(
) → String - 获取最近一次登录的TOKEN
-
getUid(
) → String - 获取最近一次登录的加密用户ID
-
hadLogin(
) → bool - 是否已登录
-
initSdk(
{required String appId, required LiveEnv env, bool debug = false, LiveSdkCallback? callback}) → Future< bool> -
初始化
appId商户idenv请求环境debugtrue:打印log;false:无log 返回值:true:初始化成功;false:初始化失败 -
isDebug(
) → bool -
loginSDK(
{required String uid, required String token, dynamic callback(bool success, String msg)?}) → void -
登录SDK
uid渠道方用户ID(商户)token直播校验tokencallback登录回调 -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setApiDomain(
String? domain) → void - 设置通信域名
-
tokenExpired(
) → void - token过期
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → LiveSdkManager
-
no setter
Constants
- appVersion → const String
- 对应的观众端版本号
- appVersionCode → const String
- package → const String
- package名称,千万不要改。所有使用assets图片的控件需要指定该package。 参考ImageView中assetImage的package设置, 最好使用直接使用ImageView
- sdkVersion → const String
- 对应的sdk版本号