BallStyle class

球的样式

Constructors

BallStyle({double size = 10.0, Color color = Colors.white, BallType ballType = BallType.solid, double borderWidth = 0.0, Color borderColor = Colors.white})
const

Properties

ballType BallType
球的类型 BallType
final
borderColor Color
边框颜色
final
borderWidth double
边框宽
final
color Color
实心球颜色
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double
尺寸
final

Methods

copyWith({double? size, Color? color, BallType? ballType, double? borderWidth, Color? borderColor}) BallStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override