Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
appBar({String? titleStr, Widget? title, Widget? left, Widget? right, dynamic backTap()?, bool canGoBack = true, Color foregroundColor = const Color(0xff333333), IconThemeData? iconTheme = const IconThemeData(color: Color(0xff37383b)), IconThemeData? actionsIconTheme = const IconThemeData(color: Color(0xff37383b)), BoxDecoration? backDecoration, TextStyle titleTextStyle = const TextStyle(fontSize: 18, fontWeight: FontWeight.w600, color: Color(0xff37383b)), SystemUiOverlayStyle statusStyle = SystemUiOverlayStyle.dark})
→ PreferredSizeWidget
-
导航栏 已添加字段不满足时,请自行补充;无特殊需要,只赋值自己需要的内容即可
-
enableButton({double width = 252, double height = 44, int tag = 0, bool enabled = true, BoxDecoration? normalBoxDecoration, BoxDecoration? disabledBoxDecoration, dynamic onTap()?})
→ Widget
-
是否可点击按钮
-
iconTextButton({double width = 60, double height = 44, int tag = 0, bool isSelected = false, bool enabled = true, double space = 0, ImageDirection direction = ImageDirection.left, required Widget image, required Widget title, BoxDecoration? normalBoxDecoration, BoxDecoration? disabledBoxDecoration, BoxDecoration? selectedDecoration, dynamic onTap()?})
→ Widget
-
图文按钮
-
imageButton({double width = 44, double height = 44, int tag = 0, required ImageProvider<Object> normalImage, ImageProvider<Object>? selectedImage, bool? isSelected, dynamic onTap()?})
→ Widget
-
图片按钮(是否选中)
-
linearGradientButton({double width = 252, double height = 44, int tag = 0, List<Color> colors = const [Color(0xFFFF223B), Color(0xFFFF9239)], AlignmentGeometry begin = Alignment.topCenter, AlignmentGeometry end = Alignment.bottomCenter, LinearGradient? gradient, double radius = 0, String? title, Widget? child, dynamic onTap()?})
→ Widget
-
线性渐变按钮
-
textButton({double width = 60, double height = 44, int tag = 0, bool isSelected = false, bool enabled = true, required Widget title, BoxDecoration? normalBoxDecoration, BoxDecoration? disabledBoxDecoration, BoxDecoration? selectedDecoration, dynamic onTap()?})
→ Widget
-
文字按钮